@@ -16,8 +16,10 @@ import sys
 import schema_markdown
 import urllib3
 
-from .grok import grok_chat
-from .ollama import ollama_chat
+from .claude import claude_chat, claude_list
+from .gpt import gpt_chat, gpt_list
+from .grok import grok_chat, grok_list
+from .ollama import ollama_chat, ollama_list
 
 
 def main(argv=None):
@@ -25,6 +27,10 @@ def main(argv=None):
     ctxkit command-line script main entry point
     """
 
+    # Combine the command-line and environment arguments
+    argv_env = os.getenv('CTXKIT_FLAGS', '').split()
+    argv_combined = argv_env + (sys.argv[1:] if argv is None else argv)
+
     # Command line arguments
     parser = argparse.ArgumentParser(prog='ctxkit')
     parser.add_argument('-g', '--config-help', action='store_true', help='display the JSON configuration file format')
@@ -52,42 +58,59 @@ def main(argv=None):
     dir_group.add_argument('-x', '--ext', action='append', default=[], help='add a directory text file extension')
     dir_group.add_argument('-l', '--depth', metavar='INT', type=int, default=0, help='the maximum directory depth, default is 0 (infinite)')
     api_group = parser.add_argument_group('API Calling')
-    group = api_group.add_mutually_exclusive_group()
-    group.add_argument('--ollama', metavar='MODEL', help='pass to the Ollama API')
-    group.add_argument('--grok', metavar='MODEL', help='pass to the Grok API')
+    api_group.add_argument('--claude', metavar='MODEL', dest='models', action=TypedItemAction, item_type='claude',
+                           help='pass to the Claude API')
+    api_group.add_argument('--gpt', metavar='MODEL', dest='models', action=TypedItemAction, item_type='gpt',
+                           help='pass to the ChatGPT API')
+    api_group.add_argument('--grok', metavar='MODEL', dest='models', action=TypedItemAction, item_type='grok',
+                           help='pass to the Grok API')
+    api_group.add_argument('--ollama', metavar='MODEL', dest='models', action=TypedItemAction, item_type='ollama',
+                           help='pass to the Ollama API')
+    api_group.add_argument('--noapi', nargs=0, dest='models', action=TypedItemAction, item_type='noapi',
+                           help='pass to no API')
+    api_group.add_argument('--list', metavar='API', help='list available models for the API (i.e. "ollama")')
     api_group.add_argument('--temp', metavar='NUM', type=float, help='set the model response temperature')
     api_group.add_argument('--topp', metavar='NUM', type=float, help='set the model response top_p')
     api_group.add_argument('--maxtok', metavar='NUM', type=int, help='set the model response max tokens')
-    args = parser.parse_args(args=argv)
-    model_type, _ = _get_model_args(args)
+    args = parser.parse_args(args=argv_combined)
+    model_type = args.models[-1][0] if args.models and args.models[-1][0] != 'noapi' else None
 
     # Show configuration file format?
     if args.config_help:
         print(CTXKIT_SMD.strip())
         return
 
-    # Load the config file
-    config = {'items': []}
-    for item_type, item_value in (args.items or []):
-        if item_type == 'config':
-            config['items'].append({'config': item_value})
-        elif item_type == 'include':
-            config['items'].append({'include': item_value})
-        elif item_type == 'template':
-            config['items'].append({'template': item_value})
-        elif item_type == 'file':
-            config['items'].append({'file': item_value})
-        elif item_type == 'dir':
-            config['items'].append({'dir': {'path': item_value, 'exts': args.ext, 'depth': args.depth}})
-        elif item_type == 'var':
-            config['items'].append({'var': {'name': item_value[0], 'value': item_value[1]}})
-        else: # item_type == 'message':
-            config['items'].append({'message': item_value})
-
     # Initialize urllib3 PoolManager
     pool_manager = urllib3.PoolManager()
 
     try:
+        # List models?
+        if args.list:
+            list_funcs = _API_FUNCTIONS.get(args.list)
+            if not list_funcs:
+                parser.error(f'Invalid model API "{args.list}"')
+            models = list_funcs['list'](pool_manager)
+            print('\n'.join(sorted(models)))
+            return
+
+        # Load the config file
+        config = {'items': []}
+        for item_type, item_value in (args.items or []):
+            if item_type == 'config':
+                config['items'].append({'config': item_value})
+            elif item_type == 'include':
+                config['items'].append({'include': item_value})
+            elif item_type == 'template':
+                config['items'].append({'template': item_value})
+            elif item_type == 'file':
+                config['items'].append({'file': item_value})
+            elif item_type == 'dir':
+                config['items'].append({'dir': {'path': item_value, 'exts': args.ext, 'depth': args.depth}})
+            elif item_type == 'var':
+                config['items'].append({'var': {'name': item_value[0], 'value': item_value[1]}})
+            else: # item_type == 'message':
+                config['items'].append({'message': item_value})
+
         # Get the system prompt
         system_prompt = DEFAULT_SYSTEM
         if args.system is not None:
@@ -152,8 +175,9 @@ def main(argv=None):
 DEFAULT_SYSTEM = '''\
 You are a helpful assistant that can read and modify files provided in the prompt.
 
-When outputting modified or new files, always provide the complete, updated content of the entire
-file, not just the modified parts. Use this format:
+You can read and modify files provided in the prompt. When outputting modified or new files, always
+provide the complete, updated content of the entire file, not just the modified parts. Use this
+format:
 
 <filename>
 <complete content of the file>
@@ -165,15 +189,27 @@ To delete a file, use:
 ctxkit: delete
 </filename>
 
-All output files should have an end-of-file newline.
+Files containing the inline instructions, lines or code comments that begin with "ctxkit:" followed
+by instructions, are modified per the instructions and the inline instructions removed. Only process
+instructions specifically prefixed with "ctxkit:" and ignore instructions intended for others (e.g.
+"user:").
+
+<filename>
+    # ctxkit: Add a docstring
+    def foo():
+        pass
+</filename>
+
 Do not output files that have not changed.
 You can include explanatory text outside of these file tags.'''
 
 
-# Map of model type (e.g. 'ollama') to model API function
+# Map of model API (e.g. 'ollama') to model API function
 _API_FUNCTIONS = {
-    'grok': grok_chat,
-    'ollama': ollama_chat
+    'claude': {'chat': claude_chat, 'list': claude_list},
+    'gpt': {'chat': gpt_chat, 'list': gpt_list},
+    'grok': {'chat': grok_chat, 'list': grok_list},
+    'ollama': {'chat': ollama_chat, 'list': ollama_list}
 }
 
 
@@ -195,17 +231,10 @@ class TypedItemAction(argparse.Action):
         items.append((self.item_type, values))
 
 
-# Helper to get the model_type and model_name
-def _get_model_args(args):
-    model_type = (args.ollama and 'ollama') or (args.grok and 'grok')
-    model_name = args.ollama or args.grok
-    return model_type, model_name
-
-
 # Helper to output the response from stdin to passed to an API
 def _output_api_call(args, pool_manager, output, system_prompt, prompt):
-    model_type, model_name = _get_model_args(args)
-    api_func = _API_FUNCTIONS[model_type]
+    model_type, model_name = args.models[-1] if args.models else (None, None)
+    api_func = _API_FUNCTIONS[model_type]['chat']
 
     # Write the response to the output
     chunks = []
@@ -253,7 +282,8 @@ def _extract_files(response, backup):
 
         # Write the file
         with open(file_path, 'w', encoding='utf-8') as file_:
-            file_.write(content)
+            file_.write(content.strip())
+            file_.write('\n')
 
 
 _R_FILENAME_TAG = re.compile(r'^<([^<>]+)>\n(.*)\n</\1>', re.DOTALL | re.MULTILINE)
